@@ -8,6 +8,7 @@ from typing import Dict, List, NamedTuple, Optional
 import inject
 import structlog
 from evergreen import Version
+from requests.exceptions import HTTPError
 
 from db_contrib_tool.config import (
     SETUP_REPRO_ENV_CONFIG_FILE,
@@ -121,6 +122,7 @@ class ArtifactDiscoveryService:
         requested_variant: Optional[str],
         target: DownloadTarget,
         ignore_failed_push: bool,
+        fallback_to_master: bool,
         starting_commit: Optional[str] = None,
     ) -> Optional[EvgURLInfo]:
         """
@@ -130,12 +132,13 @@ class ArtifactDiscoveryService:
         :param requested_variant: Name of build variant that was requested.
         :param target: Attributes of the build variant to download from.
         :param ignore_failed_push: Whether a failed push should raise an exception.
+        :param fallback_to_master: Fallback to the master branch if binaries were not found.
         :param starting_commit: When scanning multiple commits, start scanning after this commit.
         :return: Links to found artifacts.
         """
-        urls_info = None
+        artifact_urls = None
         if request.request_type == RequestType.EVG_VERSION:
-            urls_info = self.find_artifact_urls_for_version(
+            artifact_urls = self.find_artifact_urls_for_version(
                 request.identifier, requested_variant, target, ignore_failed_push
             )
 
@@ -143,14 +146,14 @@ class ArtifactDiscoveryService:
             task = self.evg_service.get_task(request.identifier)
             if requested_variant is None:
                 requested_variant = task.build_variant
-            urls_info = self.find_artifact_urls_for_version(
+            artifact_urls = self.find_artifact_urls_for_version(
                 task.version_id, requested_variant, target, ignore_failed_push
             )
 
         elif request.request_type == RequestType.GIT_BRANCH:
             mongo_project = f"{PROJECT_PREFIX}{request.identifier}"
             try:
-                urls_info = self.scan_for_artifact_urls(
+                artifact_urls = self.scan_for_artifact_urls(
                     mongo_project, requested_variant, target, ignore_failed_push, starting_commit
                 )
             except MissingBuildVariantError:
@@ -161,7 +164,7 @@ class ArtifactDiscoveryService:
                         mongo_project=mongo_project,
                         other_project=other_project,
                     )
-                    urls_info = self.scan_for_artifact_urls(
+                    artifact_urls = self.scan_for_artifact_urls(
                         other_project,
                         requested_variant,
                         target,
@@ -173,10 +176,27 @@ class ArtifactDiscoveryService:
 
         elif request.request_type == RequestType.MONGO_RELEASE_VERSION:
             mongo_project = f"{PROJECT_PREFIX}v{request.identifier}"
-            urls_info = self.scan_for_artifact_urls(
-                mongo_project, requested_variant, target, ignore_failed_push
-            )
-            if urls_info is None:
+            try:
+                artifact_urls = self.scan_for_artifact_urls(
+                    mongo_project, requested_variant, target, ignore_failed_push
+                )
+            except HTTPError as err:
+                if err.response.status_code == 404 and fallback_to_master:
+                    LOGGER.warning(
+                        "Unable to find requested mongo version, falling back to default branch",
+                        requested_version=request.identifier,
+                        default_branch=BRANCH_FALLBACK,
+                    )
+                    return self.find_artifacts(
+                        RequestTarget.previous_release(BRANCH_FALLBACK),
+                        requested_variant,
+                        target,
+                        ignore_failed_push,
+                        False,
+                    )
+                raise
+
+            if artifact_urls is None:
                 # This may be a new branch that hasn't had any artifacts built yet, so for that
                 # case, we will fallback to searching the master branch for usable artifacts.
                 self.handle_new_branch_fallback(
@@ -186,19 +206,19 @@ class ArtifactDiscoveryService:
         elif request.request_type == RequestType.MONGO_PATCH_VERSION:
             tag = f"r{request.identifier}"
             commit = self.git_service.get_commit_from_tag(tag)
-            urls_info = self.find_artifact_urls_for_commit(
+            artifact_urls = self.find_artifact_urls_for_commit(
                 commit, requested_variant, target, ignore_failed_push
             )
 
         elif request.request_type == RequestType.GIT_COMMIT:
-            urls_info = self.find_artifact_urls_for_commit(
+            artifact_urls = self.find_artifact_urls_for_commit(
                 request.identifier, requested_variant, target, ignore_failed_push
             )
 
         else:
             raise ValueError(f"Unknown RequestType: '{request.request_type}'")
 
-        return urls_info
+        return artifact_urls
 
     def handle_new_branch_fallback(
         self,
@@ -227,7 +247,12 @@ class ArtifactDiscoveryService:
 
         request = RequestTarget(request_type=RequestType.GIT_BRANCH, identifier=BRANCH_FALLBACK)
         return self.find_artifacts(
-            request, requested_variant, target, ignore_failed_push, starting_commit=merge_base
+            request,
+            requested_variant,
+            target,
+            ignore_failed_push,
+            fallback_to_master=False,
+            starting_commit=merge_base,
         )
 
     def find_artifact_urls_for_version(
