@@ -1,17 +1,4 @@
-"""Script for symbolizing MongoDB stack traces.
-
-To use as a script, paste the JSON object on the line after ----- BEGIN BACKTRACE ----- into the
-standard input of this script.
-
-Sample usage:
-
-db-contrib-tool symbolize --symbolizer-path=/path/to/llvm-symbolizer < /file/with/stacktrace
-or more simply:
-db-contrib-tool symbolize < file/with/stackraces
-
-You can also pass --output-format=json, to get rich json output. It shows some extra information,
-but emits json instead of plain text.
-"""
+"""Script for symbolizing MongoDB stack traces."""
 
 import json
 import os
@@ -28,7 +15,6 @@ import requests
 from tenacity import Retrying, retry_if_result, stop_after_delay, wait_fixed
 
 from db_contrib_tool.clients.io_client import IOClient
-from db_contrib_tool.plugin import PluginInterface, Subcommand, SubcommandResult
 from db_contrib_tool.symbolizer.mongo_log_parser_service import (
     BINARY_LOAD_ADDRESS_KEY,
     BUILD_ID_KEY,
@@ -43,8 +29,6 @@ from db_contrib_tool.utils.oauth import (
     get_oauth_credentials,
 )
 
-SUBCOMMAND = "symbolize"
-
 SYMBOLIZER_PATH_ENV = "MONGOSYMB_SYMBOLIZER_PATH"
 DEFAULT_SYMBOLIZER_PATH = "/opt/mongodbtoolchain/v4/bin/llvm-symbolizer"
 
@@ -698,125 +682,3 @@ class SymbolizerOrchestrator:
                         path=frame.get("path", "no value found")
                     )
                 )
-
-
-class Symbolizer(Subcommand):
-    """Main class for the symbolizer subcommand."""
-
-    def __init__(
-        self,
-        symbolizer_path: str,
-        dsym_hint: List[str],
-        input_format: str,
-        output_format: str,
-        live: bool,
-        host: str,
-        cache_dir: str,
-        total_seconds_for_retries: int,
-        client_secret: str,
-        client_id: str,
-    ):
-        """Initialize."""
-
-        self.symbolizer_params = SymbolizerParameters(
-            symbolizer_path=symbolizer_path,
-            dsym_hint=dsym_hint,
-            input_format=InputFormat.CLASSIC if input_format == "classic" else InputFormat.THIN,
-            output_format=OutputFormat.CLASSIC if output_format == "classic" else OutputFormat.JSON,
-            live=live,
-            host=host,
-            cache_dir=cache_dir,
-            total_seconds_for_retries=total_seconds_for_retries,
-            client_secret=client_secret,
-            client_id=client_id,
-        )
-
-        self.dbg_path_resolver = PathResolver(
-            host=self.symbolizer_params.host,
-            cache_dir=self.symbolizer_params.cache_dir,
-            client_secret=self.symbolizer_params.client_secret,
-            client_id=self.symbolizer_params.client_id,
-        )
-
-    def execute(self) -> SubcommandResult:
-        """Execute symbolize subcommand."""
-
-        def dependencies(binder: inject.Binder) -> None:
-            """Define dependencies for execution."""
-            binder.bind(PathResolver, self.dbg_path_resolver)
-
-        inject.configure(dependencies)
-        symbolize_orchestrator = inject.instance(SymbolizerOrchestrator)
-
-        success = symbolize_orchestrator.execute(self.symbolizer_params)
-        if success:
-            return SubcommandResult.SUCCESS
-        return SubcommandResult.FAIL
-
-
-class SymbolizerPlugin(PluginInterface):
-    """CLI plugin for Symbolizer."""
-
-    def parse(self, subcommand, parser, parsed_args, **kwargs):
-        """Evaluate parsed args from cli."""
-
-        if subcommand != SUBCOMMAND:
-            return None
-
-        return Symbolizer(
-            symbolizer_path=parsed_args.symbolizer_path,
-            dsym_hint=parsed_args.dsym_hint,
-            input_format=parsed_args.input_format,
-            output_format=parsed_args.output_format,
-            live=parsed_args.live,
-            host=parsed_args.host,
-            cache_dir=parsed_args.cache_dir,
-            total_seconds_for_retries=parsed_args.total_seconds_for_retries,
-            client_secret=parsed_args.client_secret,
-            client_id=parsed_args.client_id,
-        )
-
-    def add_subcommand(self, subparsers):
-        parser = subparsers.add_parser(SUBCOMMAND, help=__doc__)
-        parser.add_argument(
-            "--symbolizer-path", default="", help="Path to llvm-symbolizer executable."
-        )
-        parser.add_argument(
-            "--dsym-hint",
-            default=[],
-            action="append",
-            help="`-dsym-hint` flag values to pass to llvm-symbolizer.",
-        )
-
-        parser.add_argument(
-            "--input-format",
-            choices=["classic", "thin"],
-            default="classic",
-            help="Input mongo log format type.",
-        )
-        parser.add_argument(
-            "--output-format",
-            choices=["classic", "json"],
-            default="classic",
-            help='"json" shows some extra information',
-        )
-
-        parser.add_argument("--live", action="store_true", help="Enter live mode.")
-
-        parser.add_argument(
-            "--host", default="", help="URL of web service running the API to get debug symbol URL"
-        )
-        # caching mechanism is currently not fully developed and needs more advanced cleaning techniques,
-        # we add an option to enable it after completing the implementation.
-        parser.add_argument(
-            "--cache-dir", default="", help="Full path to a directory to store cache/files"
-        )
-        parser.add_argument(
-            "--total-seconds-for-retries",
-            default=0,
-            type=int,
-            help="Timeout for getting data from web service.",
-        )
-
-        parser.add_argument("--client-secret", default="", help="Secret key for Okta Oauth")
-        parser.add_argument("--client-id", default="", help="Client id for Okta Oauth")
