@@ -1,10 +1,12 @@
 """Usage data collecting and storing in external sources."""
 import os
 import uuid
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import analytics
+import click
 import yaml
+from pydantic import BaseModel
 
 from db_contrib_tool.config import SEGMENT_WRITE_KEY
 
@@ -24,6 +26,37 @@ ANONYMOUS_ID = str(uuid.uuid4())
 analytics.write_key = SEGMENT_WRITE_KEY
 
 
+class CommandUsage(BaseModel):
+    """
+    Command usage information.
+
+    * command: Name of subcommand being invoked.
+    """
+
+    command: Optional[str]
+
+
+class CommandWithUsageTracking(click.Command):
+    """Class to track click command usage."""
+
+    def invoke(self, ctx) -> Any:
+        """
+        Given a context, this invokes the attached callback (if it exists) in the right way.
+
+        :param ctx: Invocation context for this command.
+        :return: Invocation result.
+        """
+        ctx.ensure_object(CommandUsage)
+        track_usage(
+            event="Command Line Tool Invoked",
+            properties={
+                "command": ctx.obj.command,
+                "parsed_arguments": ctx.params,
+            },
+        )
+        return super().invoke(ctx)
+
+
 def track_usage(event: str, properties: Dict[str, Any]) -> None:
     """Track event.
 
